import * as cloudfront from '@aws-cdk/aws-cloudfront';
import { Construct } from '@aws-cdk/core';
/**
 * @experimental
 */
export interface BasicSiteConfiguration {
    /**
     * (experimental) Local path to the website folder you want to deploy on S3.
     *
     * @experimental
     */
    readonly websiteFolder: string;
    /**
     * (experimental) The index document of the website.
     *
     * @experimental
     */
    readonly indexDoc: string;
    /**
     * (experimental) The error document of the website.
     *
     * @default - No error document.
     * @experimental
     */
    readonly errorDoc?: string;
    /**
     * (experimental) Hosted Zone used to create the DNS record for the website.
     *
     * @experimental
     */
    readonly hostedZone: string;
}
/**
 * @experimental
 */
export interface CloudfrontSiteConfiguration {
    /**
     * (experimental) Local path to the website folder you want to deploy on S3.
     *
     * @experimental
     */
    readonly websiteFolder: string;
    /**
     * (experimental) The index document of the website.
     *
     * @experimental
     */
    readonly indexDoc: string;
    /**
     * (experimental) The error document of the website.
     *
     * @default - No error document.
     * @experimental
     */
    readonly errorDoc?: string;
    /**
     * (experimental) Hosted Zone used to create the DNS record for the website.
     *
     * @experimental
     */
    readonly hostedZone: string;
    /**
     * (experimental) Used to deploy a Cloudfront site with a single domain.
     *
     * e.g. sample.example.com
     * If you include a value for both domain and subDomain,
     * an error will be thrown.
     *
     * @default - no value
     * @experimental
     */
    readonly domain?: string;
    /**
     * (experimental) The sub-domain name you want to deploy.
     *
     * e.g. www.example.com
     * If you include a value for both domain and subDomain,
     * an error will be thrown.
     *
     * @default - no value
     * @experimental
     */
    readonly subDomain?: string;
    /**
     * (experimental) The price class determines how many edge locations CloudFront will use for your distribution.
     *
     * @default PriceClass.PRICE_CLASS_100.
     * @see https://aws.amazon.com/cloudfront/pricing/.
     * @experimental
     */
    readonly priceClass?: cloudfront.PriceClass;
}
/**
 * @experimental
 */
export declare class CreateBasicSite extends Construct {
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: BasicSiteConfiguration);
}
/**
 * @experimental
 */
export declare class CreateCloudfrontSite extends Construct {
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: CloudfrontSiteConfiguration);
}
